@@ -2,7 +2,7 @@
 # PODNAME: ali2phylip.pl
 # ABSTRACT: Convert ALI files to PHYLIP files
 # CONTRIBUTOR: Arnaud DI FRANCO <arnaud.difranco@gmail.com>
-# CONTRIBUTOR: Raphael LEONARD <rleonard@doct.ulg.ac.be>
+# CONTRIBUTOR: Raphael LEONARD <rleonard@doct.uliege.be>
 
 use Modern::Perl '2011';
 use autodie;
@@ -142,7 +142,7 @@ ali2phylip.pl - Convert ALI files to PHYLIP files
 
 =head1 VERSION
 
-version 0.173470
+version 0.173500
 
 =head1 USAGE
 
@@ -278,7 +278,7 @@ Arnaud DI FRANCO <arnaud.difranco@gmail.com>
 
 =item *
 
-Raphael LEONARD <rleonard@doct.ulg.ac.be>
+Raphael LEONARD <rleonard@doct.uliege.be>
 
 =back
 
