@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # PODNAME: map-gis-ali.pl
 # ABSTRACT: Build a GI-to-taxid id mapper from GI numbers in ALI files
-# CONTRIBUTOR: Loic MEUNIER <loic.meunier@doct.ulg.ac.be>
+# CONTRIBUTOR: Loic MEUNIER <loic.meunier@doct.uliege.be>
 
 use Modern::Perl '2011';
 use autodie;
@@ -43,7 +43,7 @@ map-gis-ali.pl - Build a GI-to-taxid id mapper from GI numbers in ALI files
 
 =head1 VERSION
 
-version 0.173470
+version 0.173500
 
 =head1 USAGE
 
@@ -105,7 +105,7 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =for stopwords Loic MEUNIER
 
-Loic MEUNIER <loic.meunier@doct.ulg.ac.be>
+Loic MEUNIER <loic.meunier@doct.uliege.be>
 
 =head1 COPYRIGHT AND LICENSE
 
