@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # PODNAME: tab2mapper.pl
 # ABSTRACT: Build an id mapper from a tabular file giving annotation strings.
-# CONTRIBUTOR: Loic MEUNIER <loic.meunier@doct.ulg.ac.be>
+# CONTRIBUTOR: Loic MEUNIER <loic.meunier@doct.uliege.be>
 
 use Modern::Perl '2011';
 use autodie;
@@ -47,7 +47,7 @@ tab2mapper.pl - Build an id mapper from a tabular file giving annotation strings
 
 =head1 VERSION
 
-version 0.173470
+version 0.173500
 
 =head1 USAGE
 
@@ -111,7 +111,7 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =for stopwords Loic MEUNIER
 
-Loic MEUNIER <loic.meunier@doct.ulg.ac.be>
+Loic MEUNIER <loic.meunier@doct.uliege.be>
 
 =head1 COPYRIGHT AND LICENSE
 
