@@ -1,8 +1,8 @@
 package Bio::MUST::Core::Ali;
 # ABSTRACT: Multiple sequence alignment
-# CONTRIBUTOR: Catherine COLSON <ccolson@student.ulg.ac.be>
+# CONTRIBUTOR: Catherine COLSON <ccolson@doct.uliege.be>
 # CONTRIBUTOR: Arnaud DI FRANCO <arnaud.difranco@gmail.com>
-$Bio::MUST::Core::Ali::VERSION = '0.173470';
+$Bio::MUST::Core::Ali::VERSION = '0.173500';
 use Moose;
 use namespace::autoclean;
 
@@ -720,7 +720,7 @@ Bio::MUST::Core::Ali - Multiple sequence alignment
 
 =head1 VERSION
 
-version 0.173470
+version 0.173500
 
 =head1 SYNOPSIS
 
@@ -1317,7 +1317,7 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =item *
 
-Catherine COLSON <ccolson@student.ulg.ac.be>
+Catherine COLSON <ccolson@doct.uliege.be>
 
 =item *
 
