@@ -1,8 +1,8 @@
 package Bio::MUST::Core::Seq;
 # ABSTRACT: Nucleotide or protein sequence
-# CONTRIBUTOR: Catherine COLSON <ccolson@student.ulg.ac.be>
+# CONTRIBUTOR: Catherine COLSON <ccolson@doct.uliege.be>
 # CONTRIBUTOR: Arnaud DI FRANCO <arnaud.difranco@gmail.com>
-$Bio::MUST::Core::Seq::VERSION = '0.173470';
+$Bio::MUST::Core::Seq::VERSION = '0.173500';
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 use namespace::autoclean;
@@ -347,7 +347,7 @@ Bio::MUST::Core::Seq - Nucleotide or protein sequence
 
 =head1 VERSION
 
-version 0.173470
+version 0.173500
 
 =head1 SYNOPSIS
 
@@ -419,7 +419,7 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =item *
 
-Catherine COLSON <ccolson@student.ulg.ac.be>
+Catherine COLSON <ccolson@doct.uliege.be>
 
 =item *
 
