@@ -1,8 +1,8 @@
 package Bio::MUST::Core::SeqMask;
 # ABSTRACT: Sequence mask for selecting specific sites
-# CONTRIBUTOR: Catherine COLSON <ccolson@student.ulg.ac.be>
-# CONTRIBUTOR: Raphael LEONARD <rleonard@doct.ulg.ac.be>
-$Bio::MUST::Core::SeqMask::VERSION = '0.173470';
+# CONTRIBUTOR: Catherine COLSON <ccolson@doct.uliege.be>
+# CONTRIBUTOR: Raphael LEONARD <rleonard@doct.uliege.be>
+$Bio::MUST::Core::SeqMask::VERSION = '0.173500';
 use Moose;
 use namespace::autoclean;
 
@@ -315,7 +315,7 @@ sub ideal_mask {
     # my @seqs = $ali->all_seqs;
     # $pl->foreach( \@ranges, sub {
     #     for my $seq (@seqs) {
-    #         $counts{$_} += $seq->state_at($_) !~ $regex for @$_;
+    #         $counts{$_} += $seq->state_at($_) !~ $regex for @{$_};
     #     }
     # } );
     #
@@ -743,7 +743,7 @@ Bio::MUST::Core::SeqMask - Sequence mask for selecting specific sites
 
 =head1 VERSION
 
-version 0.173470
+version 0.173500
 
 =head1 SYNOPSIS
 
@@ -823,11 +823,11 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =item *
 
-Catherine COLSON <ccolson@student.ulg.ac.be>
+Catherine COLSON <ccolson@doct.uliege.be>
 
 =item *
 
-Raphael LEONARD <rleonard@doct.ulg.ac.be>
+Raphael LEONARD <rleonard@doct.uliege.be>
 
 =back
 
