@@ -1,8 +1,8 @@
 package Bio::MUST::Core::Taxonomy;
 # ABSTRACT: NCBI Taxonomy one-stop shop
-# CONTRIBUTOR: Loic MEUNIER <loic.meunier@doct.ulg.ac.be>
-# CONTRIBUTOR: Mick VAN VLIERBERGHE <mvanvlierberghe@doct.ulg.ac.be>
-$Bio::MUST::Core::Taxonomy::VERSION = '0.173470';
+# CONTRIBUTOR: Loic MEUNIER <loic.meunier@doct.uliege.be>
+# CONTRIBUTOR: Mick VAN VLIERBERGHE <mvanvlierberghe@doct.uliege.be>
+$Bio::MUST::Core::Taxonomy::VERSION = '0.173500';
 use Moose;
 use namespace::autoclean;
 
@@ -19,10 +19,11 @@ use Carp;
 use Const::Fast;
 use File::Find::Rule;
 use IPC::System::Simple qw(system);
-use List::AllUtils qw(first firstidx uniq each_array each_arrayref mesh);
+use List::AllUtils qw(first firstidx uniq each_array mesh count_by max_by);
 use LWP::Simple qw(get getstore);
 use Path::Class qw(dir file);
 use POSIX;
+use Scalar::Util qw(looks_like_number);
 use Try::Tiny;
 use XML::Bare;
 
@@ -642,33 +643,60 @@ sub get_common_taxonomy_from_seq_ids {      ## no critic (RequireArgUnpacking)
     my $self    = shift;
     my @seq_ids = @_;
 
+    # setup optional threshold (if any) to first argument
+    # Note: this approach is used to preserved backwards compatibility
+    # Note: even if SeqId->full_id is a number the test works as expected
+    my $threshold = looks_like_number $seq_ids[0] ? shift @seq_ids : 1.0;
+
     # fetch lineages for all seq ids
     my @lineages = map {
         scalar $self->get_taxonomy_from_seq_id($_)  # note the scalar context
     } @seq_ids;
 
     # compute common lineage
-    return $self->_common_taxonomy(@lineages);
+    return $self->_common_taxonomy($threshold, @lineages);
 }
 
 
 sub _common_taxonomy {                      ## no critic (RequireArgUnpacking)
-    my $self     = shift;
-    my @lineages = @_;
+    my $self      = shift;
+    my $threshold = shift;
+    my @lineages  = @_;
 
     # ignore missing lineages
+    # TODO: decide whether missing lineages should be taken into account
     @lineages = grep { @{$_} ? $_ : () } @lineages;
 
+    my @common_lineage;
+
+    # original version: strict consensus
     # Note the use of a dynamically-sized multiple ArrayRef iterator
     # to walk down all lineages in parallel
-    my @common_lineage;
-    my $ea = each_arrayref(@lineages);
+    # my $ea = each_arrayref(@lineages);
+    #
+    # TAXON:
+    # while ( my @taxa = $ea->() ) {
+    #     no warnings 'uninitialized';  # avoid undef due to longer lineages
+    #     last TAXON if uniq(@taxa) > 1;
+    #     push @common_lineage, shift @taxa;
+    # }
+
+    # current version: threshold-based majority-rule consensu
+    # algorithm: at each taxonomic rank count all seen taxa
+    # if the most popular taxon is seen > threshold (w.r.t. all lineages)
+    # then continue with the lineages featuring it
+    # otherwise stop at previous taxon
+    my $n = @lineages;
 
     TAXON:
-    while ( my @taxa = $ea->() ) {
-        no warnings 'uninitialized';    # avoid undef due to longer lineages
-        last TAXON if uniq(@taxa) > 1;
-        push @common_lineage, shift @taxa;
+    for (my $i = 0; $n; $i++) {
+        my %count_for = count_by { $_->[$i] // q{} } @lineages;
+        my $taxon = max_by { $count_for{$_} } keys %count_for;
+        last TAXON unless $taxon;
+        my $taxon_n = $count_for{$taxon};
+        last TAXON if $taxon_n / $n < $threshold;
+        push @common_lineage, $taxon;
+        @lineages = grep { $_->[$i] eq $taxon } @lineages;
     }
 
     # examine context for returning plain array or ArrayRef
@@ -727,7 +755,7 @@ sub attach_taxonomies_to_internals {
 
             # store into current node their common lineage
             # ... and cut down level list to match this common lineage
-            my @common_lineage = $self->_common_taxonomy(@lineages);
+            my @common_lineage = $self->_common_taxonomy(1.0, @lineages);
             $node->set_generic('taxonomy' => \@common_lineage);
             $node->set_generic(
                 'levels' => [ @max_levels[0..$#common_lineage] ]
@@ -1503,7 +1531,7 @@ Bio::MUST::Core::Taxonomy - NCBI Taxonomy one-stop shop
 
 =head1 VERSION
 
-version 0.173470
+version 0.173500
 
 =head1 SYNOPSIS
 
@@ -1569,11 +1597,11 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =item *
 
-Loic MEUNIER <loic.meunier@doct.ulg.ac.be>
+Loic MEUNIER <loic.meunier@doct.uliege.be>
 
 =item *
 
-Mick VAN VLIERBERGHE <mvanvlierberghe@doct.ulg.ac.be>
+Mick VAN VLIERBERGHE <mvanvlierberghe@doct.uliege.be>
 
 =back
 
